=== modified file 'cronscripts/publishing/maintenance-check.py'
--- cronscripts/publishing/maintenance-check.py	2011-12-24 13:09:35 +0000
+++ cronscripts/publishing/maintenance-check.py	2012-01-03 10:35:26 +0000
@@ -2,9 +2,6 @@
 #
 # python port of the nice maintainace-check script by  Nick Barcet
 #
-# Taken from:
-#  https://code.edge.launchpad.net/~mvo/ubuntu-maintenance-check/python-port
-# (where it will vanish once taken here)
 
 import logging
 from optparse import OptionParser
@@ -16,6 +13,43 @@
 import apt
 import apt_pkg
 
+
+class UbuntuMaintenance(object):
+    """ Represents the support timeframe for a regular ubuntu release """
+
+    # architectures that are full supported (including LTS time)
+    PRIMARY_ARCHES = [
+        "i386",
+        "amd64",
+        ]
+
+    # architectures we support (but not for LTS time)
+    SUPPORTED_ARCHES = PRIMARY_ARCHES + ["armel"]
+
+    # what defines the seeds is documented in wiki.ubuntu.com/SeedManagement
+    SERVER_SEEDS = [
+        "server-ship",
+        "supported-server",
+        ]
+    DESKTOP_SEEDS = [
+        "ship",
+        "supported-desktop",
+        "supported-desktop-extra",
+        ]
+    SUPPORTED_SEEDS = ["all"]
+
+    # normal support timeframe
+    # time, seeds
+    SUPPORT_TIMEFRAME = [
+        ("18m", SUPPORTED_SEEDS),
+        ]
+
+    # distro names that we check the seeds for
+    DISTRO_NAMES = [
+        "ubuntu",
+        ]
+
+
 # This is fun! We have a bunch of cases for 10.04 LTS
 #
 #  - distro "ubuntu" follows SUPPORT_TIMEFRAME_LTS but only for
@@ -24,41 +58,44 @@
 #    considered *but* only follow SUPPORT_TIMEFRAME
 #  - anything that is in armel follows SUPPORT_TIMEFRAME
 #
-
-# codename of the lts releases
-LTS_RELEASES = ["dapper", "hardy", "lucid"]
-
-# architectures that are full supported (including LTS time)
-PRIMARY_ARCHES = ["i386", "amd64"]
-
-# architectures we support (but not for LTS time)
-SUPPORTED_ARCHES = PRIMARY_ARCHES + ["armel"]
-
-# what defines the seeds is documented in wiki.ubuntu.com/SeedManagement
-SERVER_SEEDS = ["supported-server", "server-ship"]
-DESKTOP_SEEDS = ["ship", "supported-desktop", "supported-desktop-extra"]
-SUPPORTED_SEEDS = ["all"]
-
-# normal support timeframe
-# time, seeds, arches
-SUPPORT_TIMEFRAME = [
-    ("18m", SUPPORTED_SEEDS),
-]
-
-# lts support timeframe
-# time, seeds, arches
-SUPPORT_TIMEFRAME_LTS = [
-    ("5y", SERVER_SEEDS),
-    ("3y", DESKTOP_SEEDS),
-    ("18m", SUPPORTED_SEEDS),
-]
-
-# distro names and if they get LTS support (order is important)
-DISTRO_NAMES_AND_LTS_SUPPORT = [
-    ("ubuntu", True),
-    ("kubuntu", True),
-    ("netbook", False),
-    ]
+class LucidUbuntuMaintenance(UbuntuMaintenance):
+    """ Represents the support timeframe for a 10.04 (lucid) LTS release,
+        the exact rules differ from LTS release to LTS release
+    """
+
+    # lts support timeframe, order is important, least supported must be last
+    # time, seeds
+    SUPPORT_TIMEFRAME = [
+        ("5y",  UbuntuMaintenance.SERVER_SEEDS),
+        ("3y",  UbuntuMaintenance.DESKTOP_SEEDS),
+        ("18m", UbuntuMaintenance.SUPPORTED_SEEDS),
+        ]
+
+    # on a LTS this is significant, it defines what names get LTS support
+    DISTRO_NAMES = [
+        "ubuntu",
+        "kubuntu",
+        ]
+
+
+class PreciseUbuntuMaintenance(UbuntuMaintenance):
+    """ The support timeframe for the 12.04 (precise) LTS release.
+        This changes the timeframe for desktop packages from 3y to 5y
+    """
+
+    # lts support timeframe, order is important, least supported must be last
+    # time, seeds
+    SUPPORT_TIMEFRAME = [
+        ("5y", UbuntuMaintenance.SERVER_SEEDS),
+        ("5y", UbuntuMaintenance.DESKTOP_SEEDS),
+        ("18m", UbuntuMaintenance.SUPPORTED_SEEDS),
+        ]
+
+    # on a LTS this is significant, it defines what names get LTS support
+    DISTRO_NAMES = [
+        "ubuntu",
+        ]
+
 
 # Names of the distribution releases that are not supported by this
 # tool. All later versions are supported.
@@ -312,6 +349,12 @@
     else:
         distro = "lucid"
 
+    # maintenance class to use
+    klass = globals().get("%sUbuntuMaintenance" % distro.capitalize())
+    if klass is None:
+        klass = UbuntuMaintenance
+    ubuntu_maintenance = klass()
+
     # make sure our deb-src information is up-to-date
     create_and_update_deb_src_source_list(distro)
 
@@ -326,7 +369,7 @@
 
     # go over the distros we need to check
     pkg_support_time = {}
-    for (name, lts_supported) in DISTRO_NAMES_AND_LTS_SUPPORT:
+    for name in ubuntu_maintenance.DISTRO_NAMES:
 
         # get basic structure file
         try:
@@ -336,17 +379,13 @@
             continue
 
         # get dicts of pkgname -> support timeframe string
-        support_timeframe = SUPPORT_TIMEFRAME
-        if lts_supported and distro in LTS_RELEASES:
-            support_timeframe = SUPPORT_TIMEFRAME_LTS
-        else:
-            support_timeframe = SUPPORT_TIMEFRAME
+        support_timeframe = ubuntu_maintenance.SUPPORT_TIMEFRAME
         get_packages_support_time(
             structure, name, pkg_support_time, support_timeframe)
 
     # now go over the bits in main that we have not seen (because
     # they are not in any seed and got added manually into "main"
-    for arch in PRIMARY_ARCHES:
+    for arch in ubuntu_maintenance.PRIMARY_ARCHES:
         rootdir = "./aptroot.%s" % distro
         apt_pkg.config.set("APT::Architecture", arch)
         cache = apt.Cache(rootdir=rootdir)
@@ -356,6 +395,9 @@
             logging.exception("cache.update() failed")
         cache.open()
         for pkg in cache:
+            # ignore multiarch package names
+            if ":" in pkg.name:
+                continue
             if not pkg.name in pkg_support_time:
                 pkg_support_time[pkg.name] = support_timeframe[-1][0]
                 logging.warn(
@@ -404,12 +446,12 @@
             # go over the supported arches, they are divided in
             # first-class (PRIMARY) and second-class with different
             # support levels
-            for arch in SUPPORTED_ARCHES:
+            for arch in ubuntu_maintenance.SUPPORTED_ARCHES:
                 # ensure we do not overwrite arch-specific overwrites
                 pkgname_and_arch = "%s/%s" % (pkgname, arch)
                 if pkgname_and_arch in pkg_support_time:
                     break
-                if arch in PRIMARY_ARCHES:
+                if arch in ubuntu_maintenance.PRIMARY_ARCHES:
                     # arch with full LTS support
                     print "%s %s %s" % (
                         pkgname_and_arch, SUPPORT_TAG,
@@ -419,4 +461,4 @@
                     # support_timeframe
                     print "%s %s %s" % (
                         pkgname_and_arch, SUPPORT_TAG,
-                        SUPPORT_TIMEFRAME[0][0])
+                        ubuntu_maintenance.SUPPORT_TIMEFRAME[-1][0])

